@@ -8,21 +8,19 @@ let hello _ msg =
   Logs.debug (fun m -> m "Developer information.");
   Logs.err (fun m -> m "Something bad happened.");
   Logs.warn (fun m -> m "Something bad may happen in the future.");
-  ()
+  if Logs.err_count () > 0 then 1 else 0
 
 let setup_log style_renderer level =
   Fmt_tty.setup_std_outputs ?style_renderer ();
   Logs.set_level level;
-  Logs.set_reporter (Logs_fmt.reporter ());
-  ()
-
+  Logs.set_reporter (Logs_fmt.reporter ())
 
 (* Command line interface *)
 
 open Cmdliner
 
 let setup_log =
-  let env = Arg.env_var "TOOL_VERBOSITY" in
+  let env = Cmd.Env.info "TOOL_VERBOSITY" in
   Term.(const setup_log $ Fmt_cli.style_renderer () $ Logs_cli.level ~env ())
 
 let msg =
@@ -30,8 +28,7 @@ let msg =
   Arg.(value & pos 0 string "Hello horrible world!" & info [] ~doc)
 
 let main () =
-  match Term.(eval (const hello $ setup_log $ msg, Term.info "tool")) with
-  | `Error _ -> exit 1
-  | _ -> exit (if Logs.err_count () > 0 then 1 else 0)
+  let cmd = Cmd.v (Cmd.info "tool") Term.(const hello $ setup_log $ msg) in
+  Cmd.eval' cmd
 
-let () = main ()
+let () = if !Sys.interactive then () else exit (main ())
